clear all
set mem 1g
set more off

mkdir c:\EventStudy\
mkdir c:\EventStudy\Input
mkdir c:\EventStudy\Temp
mkdir c:\EventStudy\Output

capture log close
log using "c:\EventStudy\bARC_Stata.log", replace


* --------- Firm Data ------------- *

insheet using "c:\EventStudy\Input\02_FirmData.csv", clear delimiter(";")

rename v1 co_name
rename v2 date
rename v3 closing_price_co

egen co_id = group(co_name)

gen edate = date(date, "DMY")

order co_id co_name date edate

sort co_id edate

bysort co_id: gen days_co =_n

xtset co_id days_co

gen co_ret = ln(closing_price/l.closing_price)

sort co_id edate

save "C:\EventStudy\Input\FirmData.dta", replace

keep co_name co_id
order co_name co_id
duplicates drop
sort co_name
save "C:\EventStudy\Temp\FirmIDs.dta", replace


* --------- Market Data ------------- *

insheet using "c:\EventStudy\Input\03_MarketData.csv", clear delimiter(";")

rename v1 mkt_name
rename v2 date
rename v3 closing_price_mkt
 
egen mkt_id = group(mkt_name)

gen edate = date(date, "DMY")

order mkt_id mkt_name date edate

sort mkt_id edate

bysort mkt_id: gen days_mkt =_n

xtset mkt_id days_mkt

gen mkt_ret = ln(closing_price/l.closing_price)

sort mkt_id edate

save "C:\EventStudy\Input\MarketData.dta", replace

keep mkt_name mkt_id
order mkt_name mkt_id
duplicates drop
sort mkt_name
save "C:\EventStudy\Temp\MarketIDs.dta", replace


* --------- Event Data ------------- *

insheet using "c:\EventStudy\Input\01_RequestFile.csv", clear delimiter(";")

rename v1 event_id
rename v2 co_name
rename v3 mkt_name
rename v4 date
rename v5 est_window_length
rename v6 est_window_endpointer

save "C:\EventStudy\Input\EventData.dta", replace

sort co_name
merge co_name using "C:\EventStudy\Temp\FirmIDs.dta"
drop if _m != 3
drop _merge

sort mkt_name
merge mkt_name using "C:\EventStudy\Temp\MarketIDs.dta"
drop if _m != 3
drop _merge

order event_id co_name co_id mkt_name mkt_id date 
gen edate = date(date, "DMY")
sort edate
save "C:\EventStudy\Input\EventData.dta", replace

sort co_id
summ co_id
local tot_cos = `r(max)'
forvalues i = 1/`tot_cos' {
	      local mkt_name_co_id_`i' = mkt_name[`i']
	      local mkt_id_co_id_`i' = mkt_id[`i']
	  }


* --------- Combining Firm, Market & Event Data ------------- *

sort co_id edate
merge co_id edate using "C:\EventStudy\Input\FirmData.dta"
drop _merge

forvalues i = 1/`tot_cos' {
	  if co_id == `i' {
	     replace mkt_name = "`mkt_name_co_id_`i''"
	     replace mkt_id = `mkt_id_co_id_`i''
	     }
	  }

sort mkt_id edate
merge mkt_id edate using "C:\EventStudy\Input\MarketData.dta"
drop if _m != 3
drop _merge

sort co_id edate

save "C:\EventStudy\Input\Data.dta", replace



log close


